@@ -16,10 +16,14 @@
  */
 package org.apache.wicket.core.request.mapper;
 
-import static org.hamcrest.Matchers.is;
+import static org.assertj.core.api.Assertions.assertThat;
+import static org.junit.jupiter.api.Assertions.assertEquals;
+import static org.junit.jupiter.api.Assertions.assertNull;
 
 import java.io.Serializable;
 import java.util.Locale;
+import java.util.function.Supplier;
+import java.util.regex.Pattern;
 
 import org.apache.wicket.request.IRequestHandler;
 import org.apache.wicket.request.Url;
@@ -27,26 +31,25 @@ import org.apache.wicket.request.handler.resource.ResourceReferenceRequestHandle
 import org.apache.wicket.request.mapper.parameter.INamedParameters;
 import org.apache.wicket.request.mapper.parameter.PageParameters;
 import org.apache.wicket.request.mapper.parameter.PageParametersEncoder;
-import org.apache.wicket.request.resource.IResource;
-import org.apache.wicket.request.resource.ResourceReference;
 import org.apache.wicket.request.resource.caching.FilenameWithVersionResourceCachingStrategy;
 import org.apache.wicket.request.resource.caching.IResourceCachingStrategy;
 import org.apache.wicket.request.resource.caching.IStaticCacheableResource;
 import org.apache.wicket.request.resource.caching.NoOpResourceCachingStrategy;
 import org.apache.wicket.request.resource.caching.ResourceUrl;
+import org.apache.wicket.request.resource.caching.version.IResourceVersion;
 import org.apache.wicket.request.resource.caching.version.StaticResourceVersion;
-import org.apache.wicket.util.IProvider;
 import org.apache.wicket.util.ValueProvider;
+import org.apache.wicket.util.lang.Args;
 import org.apache.wicket.util.resource.IResourceStream;
 import org.apache.wicket.util.resource.StringResourceStream;
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * @author Matej Knopp
  */
-public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceMapperTest
+class BasicResourceReferenceMapperTest extends AbstractResourceReferenceMapperTest
 {
-	private static final IProvider<IResourceCachingStrategy> NO_CACHING = new ValueProvider<IResourceCachingStrategy>(
+	private static final Supplier<IResourceCachingStrategy> NO_CACHING = new ValueProvider<>(
 		NoOpResourceCachingStrategy.INSTANCE);
 
 	private final BasicResourceReferenceMapper encoder = new BasicResourceReferenceMapper(
@@ -63,11 +66,11 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode1()
+	void decode1()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference1");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource1, h.getResource());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
@@ -78,16 +81,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode1A()
+	void decode1A()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference1?en");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		// assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class); // TODO use hamcrest or assertj
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource1, h.getResource());
 		assertEquals(Locale.ENGLISH, h.getLocale());
-		assertEquals(null, h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getStyle());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals(0, h.getPageParameters().getNamedKeys().size());
 	}
@@ -96,16 +99,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode2()
+	void decode2()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference1?p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource1, h.getResource());
-		assertEquals(null, h.getLocale());
-		assertEquals(null, h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getLocale());
+		assertNull(h.getStyle());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals("v1", h.getPageParameters().get("p1").toString());
 		assertEquals("v2", h.getPageParameters().get("p2").toString());
@@ -115,16 +118,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode2A()
+	void decode2A()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference1?-style&p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource1, h.getResource());
-		assertEquals(null, h.getLocale());
+		assertNull(h.getLocale());
 		assertEquals("style", h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals("v1", h.getPageParameters().get("p1").toString());
 		assertEquals("v2", h.getPageParameters().get("p2").toString());
@@ -134,16 +137,17 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode3()
+	void decode3()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference2/name2?en_EN");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource2, h.getResource());
 		assertEquals(new Locale("en", "en"), h.getLocale());
-		assertEquals(null, h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getStyle());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals(0, h.getPageParameters().getNamedKeys().size());
 	}
@@ -152,16 +156,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode3A()
+	void decode3A()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference2/name2?en_EN-style");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource2, h.getResource());
 		assertEquals(new Locale("en", "en"), h.getLocale());
 		assertEquals("style", h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals(0, h.getPageParameters().getNamedKeys().size());
 	}
@@ -170,7 +174,7 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode3B()
+	void decode3B()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference2/name2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
@@ -181,16 +185,17 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode4()
+	void decode4()
 	{
-		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference2/name2?en_EN&p1=v1&p2=v2");
+		Url url = Url
+			.parse("wicket/resource/" + CLASS_NAME + "/reference2/name2?en_EN&p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource2, h.getResource());
 		assertEquals(new Locale("en", "en"), h.getLocale());
-		assertEquals(null, h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getStyle());
+		assertNull(h.getVariation());
 		assertEquals("v1", h.getPageParameters().get("p1").toString());
 		assertEquals("v2", h.getPageParameters().get("p2").toString());
 	}
@@ -199,16 +204,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode5()
+	void decode5()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference3?-style");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource3, h.getResource());
-		assertEquals(null, h.getLocale());
+		assertNull(h.getLocale());
 		assertEquals("style", h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals(0, h.getPageParameters().getNamedKeys().size());
 	}
@@ -217,16 +222,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode6()
+	void decode6()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference3?-style&p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource3, h.getResource());
-		assertEquals(null, h.getLocale());
+		assertNull(h.getLocale());
 		assertEquals("style", h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals("v1", h.getPageParameters().get("p1").toString());
 		assertEquals("v2", h.getPageParameters().get("p2").toString());
@@ -237,16 +242,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode7()
+	void decode7()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference4?en-style");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource4, h.getResource());
 		assertEquals(Locale.ENGLISH, h.getLocale());
 		assertEquals("style", h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals(0, h.getPageParameters().getNamedKeys().size());
 	}
@@ -255,7 +260,7 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode7A()
+	void decode7A()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference4?sk");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
@@ -266,16 +271,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode8()
+	void decode8()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/reference4?en-style&p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource4, h.getResource());
 		assertEquals(Locale.ENGLISH, h.getLocale());
 		assertEquals("style", h.getStyle());
-		assertEquals(null, h.getVariation());
+		assertNull(h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals("v1", h.getPageParameters().get("p1").toString());
 		assertEquals("v2", h.getPageParameters().get("p2").toString());
@@ -285,16 +290,16 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode9()
+	void decode9()
 	{
-		Url url = Url.parse("wicket/resource/" + CLASS_NAME +
-			"/reference5?en--variation&p1=v1&p2=v2");
+		Url url = Url.parse("wicket/resource/" + CLASS_NAME
+			+ "/reference5?en--variation&p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource5, h.getResource());
 		assertEquals(Locale.ENGLISH, h.getLocale());
-		assertEquals(null, h.getStyle());
+		assertNull(h.getStyle());
 		assertEquals("variation", h.getVariation());
 		assertEquals(0, h.getPageParameters().getIndexedCount());
 		assertEquals("v1", h.getPageParameters().get("p1").toString());
@@ -305,12 +310,12 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void decode10()
+	void decode10()
 	{
-		Url url = Url.parse("wicket/resource/" + CLASS_NAME +
-			"/reference6?en-style-variation&p1=v1&p2=v2");
+		Url url = Url.parse("wicket/resource/" + CLASS_NAME
+			+ "/reference6?en-style-variation&p1=v1&p2=v2");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
-		assertTrue(handler instanceof ResourceReferenceRequestHandler);
+		assertThat(handler).isInstanceOf(ResourceReferenceRequestHandler.class);
 		ResourceReferenceRequestHandler h = (ResourceReferenceRequestHandler)handler;
 		assertEquals(resource6, h.getResource());
 		assertEquals(Locale.ENGLISH, h.getLocale());
@@ -325,18 +330,18 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 * https://issues.apache.org/jira/browse/WICKET-5673
 	 */
 	@Test
-	public void decode11()
+	void decode11()
 	{
 		Url url = Url.parse("wicket/resource/com.example.Scope/");
 		int score = encoder.getCompatibilityScore(getRequest(url));
-		assertThat(score, is(-1));
+		assertEquals(-1, score);
 	}
 
 	/**
 	 *
 	 */
 	@Test
-	public void encode1()
+	void encode1()
 	{
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference1,
 			null);
@@ -348,12 +353,12 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void encode2()
+	void encode2()
 	{
 		PageParameters parameters = new PageParameters();
 		parameters.set(0, "X");
-		parameters.add("p1", "v1");
-		parameters.add("p2", "v2");
+		parameters.add("p1", "v1", INamedParameters.Type.QUERY_STRING);
+		parameters.add("p2", "v2", INamedParameters.Type.QUERY_STRING);
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference1,
 			parameters);
 
@@ -365,7 +370,7 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void encode3()
+	void encode3()
 	{
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference2,
 			null);
@@ -377,25 +382,25 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void encode4()
+	void encode4()
 	{
 		PageParameters parameters = new PageParameters();
 		parameters.set(0, "X");
-		parameters.add("p1", "v1");
-		parameters.add("p2", "v2");
+		parameters.add("p1", "v1", INamedParameters.Type.QUERY_STRING);
+		parameters.add("p2", "v2", INamedParameters.Type.QUERY_STRING);
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference2,
 			parameters);
 
 		Url url = encoder.mapHandler(handler);
 		assertEquals("wicket/resource/" + CLASS_NAME + "/reference2/name2?en_EN&p1=v1&p2=v2",
-				url.toString());
+			url.toString());
 	}
 
 	/**
 	 *
 	 */
 	@Test
-	public void encode5()
+	void encode5()
 	{
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference3,
 			null);
@@ -407,25 +412,25 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void encode6()
+	void encode6()
 	{
 		PageParameters parameters = new PageParameters();
 		parameters.set(0, "X");
-		parameters.add("p1", "v1");
-		parameters.add("p2", "v2");
+		parameters.add("p1", "v1", INamedParameters.Type.QUERY_STRING);
+		parameters.add("p2", "v2", INamedParameters.Type.QUERY_STRING);
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference3,
 			parameters);
 
 		Url url = encoder.mapHandler(handler);
 		assertEquals("wicket/resource/" + CLASS_NAME + "/reference3?-style&p1=v1&p2=v2",
-				url.toString());
+			url.toString());
 	}
 
 	/**
 	 *
 	 */
 	@Test
-	public void encode7()
+	void encode7()
 	{
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference4,
 			null);
@@ -437,25 +442,25 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void encode8()
+	void encode8()
 	{
 		PageParameters parameters = new PageParameters();
 		parameters.set(0, "X");
-		parameters.add("p1", "v1");
-		parameters.add("p2", "v2");
+		parameters.add("p1", "v1", INamedParameters.Type.QUERY_STRING);
+		parameters.add("p2", "v2", INamedParameters.Type.QUERY_STRING);
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference4,
 			parameters);
 
 		Url url = encoder.mapHandler(handler);
 		assertEquals("wicket/resource/" + CLASS_NAME + "/reference4?en-style&p1=v1&p2=v2",
-				url.toString());
+			url.toString());
 	}
 
 	/**
 	 * Tests request to url encoding when style is null but variation is not
 	 */
 	@Test
-	public void encode9()
+	void encode9()
 	{
 		ResourceReferenceRequestHandler handler = new ResourceReferenceRequestHandler(reference5,
 			null);
@@ -468,7 +473,7 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 *
 	 */
 	@Test
-	public void versionStringInResourceFilename()
+	void versionStringInResourceFilename()
 	{
 		final IStaticCacheableResource resource = new IStaticCacheableResource()
 		{
@@ -481,7 +486,7 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 			}
 
 			@Override
-			public IResourceStream getCacheableResourceStream()
+			public IResourceStream getResourceStream()
 			{
 				return new StringResourceStream("foo-bar");
 			}
@@ -498,20 +503,8 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 			}
 		};
 
-		final ResourceReference reference = new ResourceReference(getClass(), "versioned",
-			Locale.ENGLISH, "style", null)
-		{
-			private static final long serialVersionUID = 1L;
-
-			@Override
-			public IResource getResource()
-			{
-				return resource;
-			}
-		};
-
 		IResourceCachingStrategy strategy = new FilenameWithVersionResourceCachingStrategy(
-			"-version-", new StaticResourceVersion("foobar"));
+			"-version-", new AlphaDigitResourceVersion("foobar"));
 
 		INamedParameters params = new PageParameters();
 		ResourceUrl url = new ResourceUrl("test.js", params);
@@ -550,7 +543,8 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 		strategy.undecorateUrl(url);
 		assertEquals("test.txt", url.getFileName());
 
-		// check a version that contains a dot which also marks the filename extension
+		// check a version that contains a dot which also marks the filename
+		// extension
 		strategy = new FilenameWithVersionResourceCachingStrategy("-version-",
 			new StaticResourceVersion("1.0.4-beta"));
 		url = new ResourceUrl("test.txt", params);
@@ -558,11 +552,44 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 		assertEquals("test-version-1.0.4-beta.txt", url.getFileName());
 	}
 
+	/**
+	 * A resource version that allows any of: alpha, digit, dash and dot charcters
+	 */
+	private static class AlphaDigitResourceVersion implements IResourceVersion
+	{
+		private static final Pattern pattern = Pattern.compile("[0-9a-z-\\.]*");
+
+		private final String version;
+
+		/**
+		 * create static version provider
+		 *
+		 * @param version
+		 *             static version string to deliver for all queries resources
+		 */
+		AlphaDigitResourceVersion(String version)
+		{
+			this.version = Args.notNull(version, "version");
+		}
+
+		@Override
+		public String getVersion(IStaticCacheableResource resource)
+		{
+			return version;
+		}
+
+		@Override
+		public Pattern getVersionPattern()
+		{
+			return pattern;
+		}
+	}
+
 	/**
 	 *
 	 */
 	@Test
-	public void requestWithEmptyFilename()
+	void requestWithEmptyFilename()
 	{
 		Url url = Url.parse("wicket/resource/" + CLASS_NAME + "/");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
@@ -573,9 +600,10 @@ public class BasicResourceReferenceMapperTest extends AbstractResourceReferenceM
 	 * Tests <a href="https://issues.apache.org/jira/browse/WICKET-3918">WICKET-3918</a>.
 	 */
 	@Test
-	public void wicket3918()
+	void wicket3918()
 	{
-		Url url = Url.parse("wicket/resource/org.apache.wicket.extensions.ajax.markup.html.modal.ModalWindow/res/");
+		Url url = Url
+			.parse("wicket/resource/org.apache.wicket.extensions.ajax.markup.html.modal.ModalWindow/res/");
 		IRequestHandler handler = encoder.mapRequest(getRequest(url));
 		assertNull(handler);
 	}
